@@ -23,7 +23,27 @@ def test_contains():
 def test_equals():
     s = intspan('1,3,5,7,9')
     assert s == set([1,3,5,7,9])
+
+def test_strict_super_or_subset():
+    s = intspan('1,3,5,7,9')
+    t = intspan('1,3,5')
+    u = intspan('0,1,3,5')
+    assert s > t
+    assert not s > u
+    assert t < s
+    assert t < u
+    assert u > t
+    assert not s < u
+    assert not s > u
     
+def test_isdisjoint():
+    s = intspan('1,3,5,7,9')
+    t = intspan('33-44')
+    u = intspan('1,3,99,299')
+    assert s.isdisjoint(t)
+    assert not s.isdisjoint(u)
+    assert t.isdisjoint(u)
+
 def test_copy():
     t = intspan('1,10')
     tt = t.copy()
@@ -31,6 +51,19 @@ def test_copy():
     assert t == tt
     assert t is not tt
     
+def test_clear():
+    s = intspan('1,2,3,5,8,13,21')
+    s.clear()
+    assert s == intspan()
+    
+def test_len():
+    s = intspan('1,2,3,5,8,13,21')
+    assert len(s) == 7
+    s.pop()
+    assert len(s) == 6
+    s.clear()
+    assert len(s) == 0
+    
 def test_merge():
     assert str(intspan('1-4,5')) ==  '1-5'
         
@@ -126,7 +159,7 @@ def test_symmetric_difference():
     assert t ^ s == t.symmetric_difference(s)
     assert t ^ t == t.symmetric_difference(t)
     
-def test_increments():
+def test_augmented_assignments():
     s = intspan('50-60')
     s |= intspan('10-20')
     assert s == intspan('10-20,50-60')
@@ -137,6 +170,16 @@ def test_increments():
     s ^= intspan('10,99')
     assert s == intspan('11-15,50-55,99')
     
+    t = intspan('50-60')
+    t.update('10-20')
+    assert t == intspan('10-20,50-60')
+    t.intersection_update('0-55')
+    assert t == intspan('10-20,50-55')
+    t.difference_update('16-20')
+    assert t == intspan('10-15,50-55')
+    t.symmetric_difference_update('10,99')
+    assert t == intspan('11-15,50-55,99')
+    
 def test_pop():
     s = intspan('100-110')
     assert s.pop() == 100
